@@ -425,6 +425,57 @@ describe 'Asciidoctor::PDF::Converter - Title Page' do
       (expect images[0].hash[:Height]).to be 240
     end
 
+    it 'should resolve title page logo image specified using path in theme relative to themesdir' do
+      pdf_theme = {
+        __dir__: fixtures_dir,
+        title_page_logo_image: 'tux.png',
+      }
+      pdf = to_pdf <<~'EOS', pdf_theme: pdf_theme
+      = Document Title
+      :doctype: book
+      EOS
+
+      images = get_images pdf, 1
+      (expect images).to have_size 1
+      (expect images[0].hash[:Width]).to be 204
+      (expect images[0].hash[:Height]).to be 240
+    end
+
+    it 'should resolve title page logo image specified using path in theme relative to themesdir in classloader', if: RUBY_ENGINE == 'jruby' do
+      require fixture_file 'pdf-themes.jar'
+      pdf = to_pdf <<~'EOS', attribute_overrides: { 'pdf-theme' => 'uri:classloader:/pdf-themes/title-page-logo-image-theme.yml' }
+      = Document Title
+      :doctype: book
+      EOS
+
+      images = get_images pdf, 1
+      (expect images).to have_size 1
+      (expect images[0].hash[:Width]).to be 204
+      (expect images[0].hash[:Height]).to be 240
+    end
+
+    it 'should resolve title page logo image with absolute path for theme loaded from classloader', if: RUBY_ENGINE == 'jruby' do
+      require fixture_file 'pdf-themes.jar'
+      pdf = to_pdf <<~'EOS', attribute_overrides: { 'pdf-theme' => 'uri:classloader:/pdf-themes/title-page-logo-image-from-fixturesdir-theme.yml', 'fixturesdir' => fixtures_dir }
+      = Document Title
+      :doctype: book
+      EOS
+
+      images = get_images pdf, 1
+      (expect images).to have_size 1
+      (expect images[0].hash[:Width]).to be 204
+      (expect images[0].hash[:Height]).to be 240
+    end
+
+    it 'should ignore missing attribute reference when resolve title page logo image from theme' do
+      (expect do
+        to_pdf <<~'EOS', pdf_theme: { title_page_logo_image: 'image:{no-such-attribute}{attribute-missing}.png[]' }, attribute_overrides: { 'attribute-missing' => 'warn' }
+        = Document Title
+        :doctype: book
+        EOS
+      end).to log_message severity: :WARN, message: '~skip.png'
+    end
+
     it 'should add remote logo specified by title_page_logo_image theme key to title page' do
       with_local_webserver do |base_url|
         [%(#{base_url}/tux.png), %(image:#{base_url}/tux.png[])].each do |image_url|
